@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 import json
 import re
+from itertools import groupby
+from operator import itemgetter
 
 import yaml
-from operator import itemgetter
-from itertools import groupby
 
 
 def doc2dict(doc):
@@ -35,6 +35,15 @@ def doc2dict(doc):
     return result
 
 
+def gen_md_table(headers: list, data: list):
+    trs = ''.join([f"<tr>{''.join([f'<td>{td}</td>' for td in tr])}</tr>" for tr in data])
+    table_str = f"<table>" \
+                f"<tr>{''.join([f'<th>{th}</th>' for th in headers])}</tr>" \
+                f"{trs}" \
+                f"</table>  \n"
+    return table_str
+
+
 def data2md_str(data, field="tag", base_url="http://127.0.0.1"):
     data.sort(key=itemgetter(field))
     api_class_str = ""
@@ -55,19 +64,17 @@ def data2md_str(data, field="tag", base_url="http://127.0.0.1"):
                     param_desc = description_info.get("param_dict", {}).get(param_name) if description_info.get(
                         "param_dict", {}).get(param_name) else ""
                     param_default = param.get('default') if param.get('default') is not None else "null"
-                    param_string = f"|{param_name}|{'true' if param.get('required') else 'false'}" \
-                                   f"|{param.get('type')}|{param_default}|{param_desc}|"
-                    param_arr.append(param_string)
+                    param_required = 'true' if param.get('required') else 'false'
+                    param_type = param.get('type')
+                    param_arr.append([param_name, param_required, param_type, param_default, param_desc])
                 elif param.get("in") == "header":
                     header_name = param.get('name')
                     header_desc = description_info.get(header_name) if description_info.get(header_name) else ""
-                    param_string = f"|{header_name}|{'true' if param.get('required') else 'false'}" \
-                                   f"|{param.get('type')}|{header_desc}|"
-                    header_arr.append(param_string)
+                    header_required = 'true' if param.get('required') else 'false'
+                    header_type = param.get('type')
+                    header_default = param.get('default') if param.get('default') is not None else "null"
+                    header_arr.append([header_name, header_required, header_type, header_default, header_desc])
                 elif param.get("in") == "body":
-                    # body_string = f"|{param.get('name')}|{'true' if param.get('required') else 'false'}" \
-                    #       f"|{param.get('schema',{}).get('type')}||"
-                    # body_arr.append(body_string)
                     schema = param.get('schema', {})
                     if schema:
                         for property_name, property_info in schema.get("properties", {}).items():
@@ -76,25 +83,31 @@ def data2md_str(data, field="tag", base_url="http://127.0.0.1"):
                                 property_name) else ""
                             property_default = property_info.get('default') if property_info.get(
                                 'default') is not None else "null"
-                            body_string = f"|{property_name}|{'true' if property_info.get('required') else 'false'}" \
-                                          f"|{property_info.get('type')}|{property_default}|{property_desc}|"
-                            body_arr.append(body_string)
+                            property_required = 'true' if property_info.get('required') else 'false'
+                            property_type = property_info.get('type')
+                            param_arr.append(
+                                [property_name, property_required, property_type, property_default, property_desc])
             api_class_str += f"\n### {index}.{i + 1} {api.get('summary')}  \n###### 请求地址  \n> <{url}>  " \
                              f"\n###### 支持格式  \n> JSON  \n###### HTTP请求方式  \n" \
-                             f"> {api.get('method').upper()}  \n###### 请求头  \n|请求头|值|说明|  " \
-                             f"\n|---|---|---|  \n|Content-Type|application/json||  "
+                             f"> {api.get('method').upper()}  \n"
+            header_arr.append(["Content-Type", "true", "string", "", "application/json"])
+            if header_arr:
+                header_table_headers = ['参数', '必选', '类型', '默认值', '说明']
+                header_str = f'###### 请求头  \n{gen_md_table(header_table_headers, header_arr)}'
+                api_class_str = f"{api_class_str}  \n{header_str}  \n"
             if param_arr:
-                param_str = '###### 请求参数  \n|参数|必选|类型|默认值|说明|  \n|---|---|---|---|---|  \n' + '\n'.join(
-                    param_arr)
-                api_class_str = f"{api_class_str}\n{param_str}\n"
+                param_table_headers = ['参数', '必选', '类型', '默认值', '说明']
+                param_str = f'###### 请求参数  \n{gen_md_table(param_table_headers, param_arr)}'
+                api_class_str = f"{api_class_str}  \n{param_str}  \n"
             if body_arr:
-                body_str = '###### 请求参数  \n|参数|必选|类型|默认值|说明|  \n|---|---|---|---|---|  \n' + '\n'.join(
-                    body_arr)
-                api_class_str = f"{api_class_str}\n{body_str}\n"
+                body_table_headers = ['参数', '必选', '类型', '默认值', '说明']
+                body_str = f'###### 请求参数  \n{gen_md_table(body_table_headers, body_arr)}'
+                api_class_str = f"{api_class_str}  \n{body_str}  \n"
             response_dict = description_info.get("response_dict", {})
             if response_dict:
-                response_arr = [f'|{k}|{v}|' for k, v in response_dict.items()]
-                api_class_str += f"###### 返回字段  \n|返回字段|说明|  \n|---|---|  \n" + '\n'.join(response_arr)
+                response_table_headers = ['参数', '说明']
+                response_arr = [[k, v] for k, v in response_dict.items()]
+                api_class_str += f"###### 返回字段  \n{gen_md_table(response_table_headers, response_arr)}  \n"
             example = description_info.get("example")
             if example:
                 api_class_str += f"\n###### 响应示例  \n```json\n{example}\n```"
